@@ -3,7 +3,8 @@
  *                                                                   
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
- *        Copyright (C) 1999, 2000, 2001, 2002, 2003 Henrik Sandklef
+ *        Copyright (C) 1999, 2000, 2001, 2002, 2003 
+ *                      2009, 2010  Henrik Sandklef
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -45,7 +46,6 @@ cnee_handle_err(int error)
       fprintf (stderr, "  Error:      %s\n", err);
       fprintf (stderr, "  Solution:   %s\n", descr);
     }
-  exit(error);
 }
 
 
@@ -62,10 +62,6 @@ int main(int argc,char *argv[])
   xnee_data *xd ;
 
 
-  /* Work around for strange bugs in X server around summet 2009 */
-  fprintf (stderr, "Sleep workaround a strange RECORD/Xtest problem around 2009 (ignore it)\n");
-  usleep (1000*300);
-
   /*  Get a new xnee_data structure  */
   xd = xnee_new_xnee_data();
   if (xd==NULL)
@@ -113,7 +109,6 @@ int main(int argc,char *argv[])
     cnee_handle_err(ret);
   }
 
-
   /* hey, we are fin(n)ished .... close down */
   xnee_close_down(xd);
   
