@@ -289,7 +289,10 @@ xnee_free_dyn_data(xnee_data *xd)
    xnee_verbose((xd, " --- xnee_free_dyn_data: xnee_info\n")); 
    ret = xnee_reset_xnee_info(xd);
    XNEE_RETURN_IF_ERR(ret);
-
+   
+   xnee_verbose((xd, " --- xnee_free_dyn_data: x version info\n")); 
+   XNEE_FREE_IF_NOT_NULL(xd->x_vendor_name);
+   
    xnee_verbose((xd, "<--- xnee_free_dyn_data\n"));
    return XNEE_OK;
 }
@@ -297,6 +300,8 @@ xnee_free_dyn_data(xnee_data *xd)
 
 
 
+
+
 /**************************************************************
  *                                                            *
  * xnee_new_xnee_data                                         *
@@ -317,9 +322,12 @@ xnee_new_xnee_data()
    }
    memset (xd, 0, sizeof(xnee_data));
    
+   xd->grab_keys=NULL; 
+
    ret = xnee_new_dyn_data(xd);
    XNEE_RETURN_NULL_IF_ERR(ret);
   
+
    ret = xnee_init(xd);
    XNEE_RETURN_NULL_IF_ERR(ret);
 
@@ -394,6 +402,7 @@ xnee_free( /*@only@*/  /*@out@*/ /*@null@*/ void *mem)
    {
       return XNEE_MEMORY_FAULT;
    }
+/*   fprintf(stderr, "Freeing at %lu\n", mem); */
    free(mem);
    return XNEE_OK;
 }
