@@ -280,7 +280,7 @@ xnee_record_handle_event_printer(xnee_data * xd,
     case ReparentNotify:
       new_window_pos = xnee_get_new_window_pos(xd);
       
-      if (xnee_is_forced_reparent_recording(xd))
+      if ( ! xnee_is_no_reparent_recording(xd))
 	{
 	  fprintf (out,"0,%u,0,0,0,0,0,%lu\n", 
 		   event_type,
@@ -883,10 +883,6 @@ xnee_unsetup_recording(xnee_data *xd)
 
   xnee_verbose((xd, "---> xnee_unsetup_recording\n"));
 
-      printf ("Close context** %u %u   context:%u *** \n",
-	      xd,
-	      xd->record_setup,
-	      xd->record_setup->rContext); fflush(stdout);
 
   if (xd->record_setup->rContext != 0)
     {
