@@ -166,9 +166,6 @@ xnee_close_down(xnee_data* xd)
       xnee_free(xd->display);
       xd->display=NULL;
     }
-  /* HESA HESA HESA */
-  if (0==1)
-    {
 
   if ( xd->control!=NULL)  
     {
@@ -186,7 +183,6 @@ xnee_close_down(xnee_data* xd)
       XCloseDisplay ( xd->fake );
     }
  
-    }
 
  XNEE_DEBUG ( (stderr ," --> xnee_close_down() at 0.4 \n"  )); 
   if ( xd->data!=NULL)  
@@ -378,7 +374,7 @@ xnee_init(xnee_data* xd)
   */
 
 
-  xd->forced_reparent_recording = 0;
+  xd->no_reparent_recording = 0;
 
   for (i=0;i<XNEE_NR_OF_TYPES;i++)
     {
