@@ -4,7 +4,7 @@
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
  *        Copyright (C) 1999, 2000, 2001, 2002, 2003, 
-                        2004, 2009  Henrik Sandklef 
+ *                      2004, 2009, 2010 Henrik Sandklef 
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -35,6 +35,7 @@
 
 
 
+
 /**************************************************************
  *                                                            *
  * xnee_write_settings_to_file                                *
@@ -490,3 +491,103 @@ xnee_str2int(xnee_data *xd, char *str)
     }
   return ret;
 }
+
+
+int 
+xnee_record_from_data_display(xnee_data *xd)
+{
+  int ret_val = 0;
+  /*
+  fprintf (stderr,"X info:   %s %d %d %d\n",
+	  xd->x_vendor_name, 
+	  xd->x_version_major, 
+	  xd->x_version_minor, 
+	  xd->x_version_minor_sub);
+  */
+  if ( (xd != NULL) && (xd->x_vendor_name != NULL ) )
+    {
+      
+      /*
+       *  Xorg
+       */
+      if (strstr(xd->x_vendor_name, "X.Org"))
+	{
+	  /*
+	   *  Version 1
+	   */
+	  if ( xd->x_version_major == 1 )
+	    {
+	      /*
+	       *  versions 1.4 - 1.7
+	       */
+	      if ( ( xd->x_version_minor >= 4 ) &&
+		   ( xd->x_version_minor <= 7 ) )
+		{
+
+		  /*
+		   *  Once the XLIB fix is in place
+		   *  this should be enabled 
+		   *
+		  if ( ( xd->x_version_minor == 7 ) &&
+		       ( xd->x_version_minor_sub > 6 ))
+		    {
+		    ;
+		    }
+		  else
+		    {
+		  */
+		      ret_val = 1;
+		      /*
+		    }
+		      */
+		}
+	    }
+	}
+      else if (strstr(xd->x_vendor_name, "Sun Microsystems") )
+	{
+	  
+	  if ( ( xd->x_version_major == 1 ) &&
+	       ( xd->x_version_minor >= 3 ) )
+	    {
+	      ret_val = 1;
+	    }
+	}
+      
+    }
+
+  return ret_val;
+}
+
+
+
+Display *
+xnee_get_display_for_recordcontext(xnee_data *xd)
+{
+  Display *context_display;
+
+  if (xd==NULL)
+    {
+      return NULL;
+    }
+
+  if ( xnee_record_from_data_display(xd))
+    {
+      /*
+       * From X.org 1.6.0 to ????
+       * 
+       *   there seem to be something strange about 
+       *   the XRecordCreateContext call
+       *   which causes the XRecordEnableContextAsync 
+       *   to fail ... ugly fix, but it works
+       *
+       */
+      fprintf(stderr, "Workaround: Creating context on data display instead of control \n");
+      fprintf(stderr, "            You can ignore this message\n");
+      context_display = xd->data ;
+    }
+  else
+    {
+      context_display = xd->control ;
+    }
+  return context_display;
+}
